Django-page-cms's documentation
===============================

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   display-content.rst
   navigation-template-tags.rst
   
   placeholders.rst
   3rd-party-apps.rst
   page-api.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

